---
id: vulnerability-scanning
name: Vulnerability Scanning
description: While much of SAFETAG focuses on digital security challenges within and around the office, remote attacks on the...
origin: https://github.com/SAFETAG/SAFETAG
origin_path: master/en/exercises/vulnerability_scanning/summary.md
---
# Vulnerability Scanning

## Summary

While much of SAFETAG focuses on digital security challenges within and around the office, remote attacks on the organization's website, extranets, and unintended information available from "open sources" all pose real threats and deserve significant attention.  SAFETAG takes great care to take a very passive approach to this work, especially when done off-site, so as not to have unintended consequences on the organization's infrastructure or undermine operational security concerns.

This activity uses active research and scanning to detect known vulnerabilities in external and key internal services. Usually penetration tests exploit possible vulnerabilities to confirm their existence. [^NIST_exploit_confirm] But, the use of exploits puts the organization's systems at a level of increased risk [^NIST_pen_test_danger] that is unacceptable when neither the organization nor the auditor has the time or finances to address the issue. The SAFETAG methodology only uses relatively safe exploitation of vulnerabilities for targeted outcomes. For instance, cracking the wireless access point password allows us to demonstrate the importance of good passwords without singling out any individual's passwords. [^network-access]


## Materials Needed

* A Kali VM, bootable USB, or installed system with OWASP ZAP or OpenVAS installed, updated, and running\

## Considerations

:[](../../methods/vulnerability_analysis/operational_security.md)

* Be very careful about which automated scans you run to ensure that no aggressive or potentially damaging tests are included.
* OpenVAS saves its scan records in /var/lib/openvas/mgr/tasks.db - this file will contain sensitive data, ensure it is stored securely.
* OpenVAS and other vulnerability scanners can be highly aggressive in their tactics.  Tools like Metasploit come with a library of active, functional exploits to "prove" that a system is actively vulnerable.  As such, these can be tricky to use.  Even OpenVAS on a safe-only scan can appear to a host as an active attack, blocking further access from your IP (this can cause some annoyance if you are, for example, scanning your host organization's website from their network).  Some of these scans and techniques -- again, even the "safe" ones -- can also be a violation of local hacking laws.  Get explicit permission, give warnings, and be careful.

## Walkthrough

:[](openvas.md)

<!-- DEPRECATED: !INCLUDE "owasp-zap.md" -->

## Recommendation

The auditor will need to do research and compare against the organization's capacity and risks to give specific recommendations based on the vulnerabilities discovered in the process.  Some common recommendations include the following:

##### Out of Date Content Manangement System
:[](../cms_version/recommendations.md)

##### Insecure Website Login
:[](../insecure_website_login/recommendations.md)



:[](../references/footnotes.md)
